package
Version:
v1.0.7
Opens a new window with list of versions in this module.
Published: Feb 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Edge struct {
EdgeID string `json:"edge_id"`
Org string `json:"org"`
Repo string `json:"repo"`
FromNodeID string `json:"from_node_id"`
ToNodeID string `json:"to_node_id"`
Rationale string `json:"rationale"`
SourceLink string `json:"source_link"`
SourceDetail string `json:"source_detail"`
}
type Graph struct {
Org string `json:"org"`
Repo string `json:"repo"`
Nodes []Node `json:"nodes"`
Edges []Edge `json:"edges"`
}
type Node struct {
NodeID string `json:"node_id"`
Org string `json:"org"`
Repo string `json:"repo"`
Kind string `json:"kind"`
FindingType string `json:"finding_type"`
ToolType string `json:"tool_type"`
Location string `json:"location"`
CanonicalKey string `json:"canonical_key"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.